import React, { Component } from 'react';
import Net from './Net';

class PresentationTable extends Component {
	constructor(props) {
		super(props);
		this.rcode = parseInt(Math.random() * 100);
	}
	render() {
		return <table className={"table table-bordered " + (this.props.small ? "table-sm" : "")}>
					<thead>
						<tr>
							<th>Κωδικος</th>
							<th>Θέση</th>
							<th>Τιμη</th>
						</tr>
					</thead>
					<tbody>
						{	(this.props.alert ? this.props.keys.reduce((future, current) => {
								if(this.props.codes[current].alert === 1)
									future.push(current);
								return future;
							}, []) : this.props.keys)
							.map((code, index) => { 
								let items = [
								<tr key={1} className="clickable" data-toggle='collapse' data-target={".c"+this.rcode+code+"col"}>
									<td>{code}</td>
									<td>{this.props.codes[code].position}</td>
									<td>{this.props.codes[code].price || ''}</td>
								</tr>];
								Object.keys(this.props.codes[code].data || {}).forEach((key, i) => {
									let item = this.props.codes[code].data[key];
									items.push(
										<tr className={"table-active c"+this.rcode+code+"col collapse"} key={i+10}>
											<td>{key}</td>
											<td>{item.position}</td>
											<td>{item.price}</td>
										</tr>
									);
								});
								return items;
							})
						}
					</tbody>
				</table>;
	}
}
class Database extends Component{
	constructor(props){
		super(props); 
		this.state = {
			codes: {}
		}

		this.getAll();
	}

	getAll() {
		return Net.get('').then((data) => this.setState({codes: data}));
	}

	add(name, value) {
		return Net.put(name, value).catch((e) => console.log(e));
	}

	save() {
		let code = document.getElementById('code').value;
		let enemies = document.getElementById('enemies').value;
		let category = document.getElementById('category').value;
		this.add(code, {category: category, enemies: enemies}).then(() => window.location.href = window.location.href);
	}

	delete() {
		let code = document.getElementById('code').value;
		return Net.del(code).then(() => window.location.href = window.location.href);
	}

	refresh() {
		Net.get('refresh').catch((data) => window.location.href = window.location.href);
	}

	render() {
		let keys = [];
		Object.keys(this.state.codes).forEach(function(key) {
	      keys.push(key);
	    });
		return <div>
			<div>
				<span>Κωδικός</span>
				<input type="text" id="code" name="code" />
				<span>Ανταγωνιστές</span>
				<input type="text" id="enemies" name="enemies" />
				<span>Κατηγορία</span>
				<select id="category" name="category" >
					<option value="926/symvata-anakataskevasmena-toner-drums-ektypwtwn">Toner</option>
					<option value="925/symvata-anakataskevasmena-melania-inkjet">Μελανακια</option>
				</select>
				<button onClick={() => this.save()}>Save</button>
				<button onClick={() => this.delete()}>Delete</button>
				<button onClick={() => this.refresh()}>Refresh</button>
			</div>
			<div className="row">
				<div className="col-6">
					<h1>All Codes</h1>
					<PresentationTable keys={keys} codes={this.state.codes} small/>
				</div>
				<div className="col-6">
					<h1>Alerts</h1>
					<PresentationTable keys={keys} codes={this.state.codes} alert/>
				</div>
				
			</div>
		</div>;
	}
}

export default Database;